OiRA

Help

1. Preparació
2. Implicació
3. Identificació + Avaluació
4. Pla d'acció
5. Informe
6. Grau d’emplenament 0%

# Adapti l'avaluació de riscos a la seva organització

Per tal d'adaptar l'avaluació de riscos a la seva organització, pot ser que se li demani el següent:

- seleccionar o ometre situacions segons la importància per a la seva activitat empresarial i marcar les caselles adequades
- enumerar diverses botigues, sucursals, unitats de l'empresa, etc. Aquests riscos relacionats es repetiran per a cada nom introduït.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More